<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>المقاسات</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>العرض:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>التباعد:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>المدة</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>تضبط بعض الإخطارات مدة عرضها على الشاشة بنفسها.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>المدة المبدئية:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> ثا</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="196"/>
        <source>Do Not Disturb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="202"/>
        <source>Only save notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>كم من واحد تريد أن يُحفظ:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>يُعرض امس التطبيق أعلى الإخطار.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>تجاهَل التطبيقات الآتية:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="17"/>
        <source>Position on screen</source>
        <translation>المكان على الشاشة</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="176"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="63"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="72"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;تحذير:&lt;/b&gt; لا عفريت إخطارات يعمل.
سأستخدم أحد الاحتياطيين.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="75"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;تحذير:&lt;/b&gt; هناك عفريت من طرف ثالث (%1) يعمل.
لن تؤثّر هذه الإعدادات عليه!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="137"/>
        <source>at top left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="139"/>
        <source>at top center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="141"/>
        <source>at top right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="143"/>
        <source>at center left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="145"/>
        <source>at center right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="147"/>
        <source>at bottom left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="149"/>
        <source>at bottom center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="151"/>
        <source>at bottom right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="153"/>
        <source>Notification demo </source>
        <translation>نموذج لإخطار </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="154"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>هذا إخطار تجريبي.
ستظهر كل الإخطارات هنا في «لكسكيوت».</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>إخطارات سطح المكتب</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
